/***************************************************************************
                          doku.cpp  -  Implementation Basisklasse (Control) Doku
                             -------------------                                         
    begin                : Wed Aug  4 17:32:35 MEST 1999
                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "doku.h"
#include "filesave.xpm"
#include "fileopen.xpm"
#include "filenew.xpm"


Doku::Doku()
{
  this->resize(640,480);
  setCaption("Dokumentenverwaltung " VERSION);
  
  ///////////////////////////////////////////////////////////////////
  // call inits to invoke all other construction parts
  initMenuBar();
  initToolBar();
  initStatusBar();

  initDoc();
  initView();  

  /** connect doc with the view*/
  connect(doc,SIGNAL(documentChanged()),view,SLOT(slotDocumentChanged()));
  connect(doc,SIGNAL(documentSaved()),view,SLOT(slotDoProgressBar()));
}

Doku::~Doku(){
}

void Doku::initMenuBar()
{
  ///////////////////////////////////////////////////////////////////
  // MENUBAR  

  ///////////////////////////////////////////////////////////////////
  // menuBar entry file_menu
  file_menu = new QPopupMenu();
  file_menu->insertItem("&New",this,SLOT(slotFileNew()),CTRL+Key_N, ID_FILE_NEW );
  file_menu->insertItem("&Open...",this,SLOT(slotFileOpen()),CTRL+Key_O, ID_FILE_OPEN );
  file_menu->insertSeparator();
  file_menu->insertItem("&Save",this,SLOT(slotFileSave()),CTRL+Key_S, ID_FILE_SAVE );
  file_menu->insertItem("Save &as",this,SLOT(slotFileSaveAs()),0, ID_FILE_SAVE_AS);
  file_menu->insertItem("&Close",this,SLOT(slotFileClose()),CTRL+Key_W, ID_FILE_CLOSE );
  file_menu->insertSeparator();
  file_menu->insertItem("E&xit",this,SLOT(slotFileQuit()),CTRL+Key_Q, ID_FILE_QUIT );

  ///////////////////////////////////////////////////////////////////
  // menuBar entry edit_menu
  edit_menu = new QPopupMenu();
  edit_menu->insertItem("Cu&t",this,SLOT(slotEditCut()),CTRL+Key_X, ID_EDIT_CUT );
  edit_menu->insertItem("&Copy",this,SLOT(slotEditCopy()),CTRL+Key_C, ID_EDIT_COPY );
  edit_menu->insertItem("&Paste",this,SLOT(slotEditPaste()),CTRL+Key_V, ID_EDIT_PASTE );
 
  
  ///////////////////////////////////////////////////////////////////
  // menuBar entry view_menu
  view_menu = new QPopupMenu();
  view_menu->setCheckable(true);
  view_menu->insertItem("Tool&bar",this,SLOT(slotViewToolBar()),0, ID_VIEW_TOOLBAR);
  view_menu->insertItem("&Statusbar",this,SLOT(slotViewStatusBar()),0, ID_VIEW_STATUSBAR );
  view_menu->setItemChecked(ID_VIEW_TOOLBAR, true);
  view_menu->setItemChecked(ID_VIEW_STATUSBAR,true);


  ///////////////////////////////////////////////////////////////////
  // menuBar entry view_menu
  doc_menu = new QPopupMenu();
  doc_menu->insertItem("&Insert",this,SLOT(slotDocInsert()),0, ID_DOC_INSERT);
  doc_menu->insertItem("&Modify",this,SLOT(slotDocModify()),0, ID_DOC_MODIFY);
  doc_menu->insertItem("&Delete",this,SLOT(slotDocDelete()),0, ID_DOC_DELETE );
  doc_menu->setItemEnabled(ID_DOC_INSERT,false);
  doc_menu->setItemEnabled(ID_DOC_MODIFY,false);
  doc_menu->setItemEnabled(ID_DOC_DELETE,false);



  ///////////////////////////////////////////////////////////////////
  // menuBar entry help_menu
  help_menu = new QPopupMenu();
  help_menu->insertItem("About...",this,SLOT(slotHelpAbout()),0,ID_HELP_ABOUT);


  ///////////////////////////////////////////////////////////////////
  // MENUBAR CONFIGURATION
  // set menuBar() the current menuBar 

  menuBar()->insertItem("&File", file_menu);
  menuBar()->insertItem("&Edit", edit_menu);
  menuBar()->insertItem("&View", view_menu);
  menuBar()->insertItem("&Document", doc_menu);
  menuBar()->insertSeparator();
  menuBar()->insertItem("&Help", help_menu);
  
  ///////////////////////////////////////////////////////////////////
  // CONNECT THE SUBMENU SLOTS WITH SIGNALS

  connect(file_menu,SIGNAL(highlighted(int)), SLOT(statusCallback(int)));
  connect(edit_menu,SIGNAL(highlighted(int)), SLOT(statusCallback(int)));
  connect(view_menu,SIGNAL(highlighted(int)), SLOT(statusCallback(int)));
  connect(doc_menu,SIGNAL(highlighted(int)), SLOT(statusCallback(int)));
  connect(help_menu,SIGNAL(highlighted(int)), SLOT(statusCallback(int)));
  
}
void Doku::initToolBar()
{

  ///////////////////////////////////////////////////////////////////
  // TOOLBAR
  QPixmap openIcon,saveIcon,newIcon;

  file_toolbar = new QToolBar( this, "file operations" );
 
  newIcon = QPixmap( filenew );
  QToolButton * fileNew = new QToolButton( newIcon, "New File", 0,this, SLOT(slotFileNew()),
					   file_toolbar);

  openIcon = QPixmap( fileopen );
  QToolButton * fileOpen = new QToolButton( openIcon, "Open File", 0,this, SLOT(slotFileOpen()),
					    file_toolbar);

  saveIcon = QPixmap( filesave );
  QToolButton * fileSave = new QToolButton( saveIcon, "Save File", 0,this, SLOT(slotFileSave()),
					    file_toolbar);
  
  
  file_toolbar->addSeparator();
  (void)QWhatsThis::whatsThisButton( file_toolbar );
  QWhatsThis::add(fileNew,"Click this button to create a new file.\n\n"
		   "You can also select the New command from the File menu.");
  QWhatsThis::add(fileOpen,"Click this button to open a new file.\n\n"
		   "You can also select the Open command from the File menu.");
  QWhatsThis::add(fileSave,"Click this button to save the file you are "
		  "editing.  You will be prompted for a file name.\n\n"
		  "You can also select the Save command from the File menu.");
  
}

void Doku::initStatusBar()
{
  ///////////////////////////////////////////////////////////////////
  //STATUSBAR
  statusBar()->message( IDS_DEFAULT, 2000 );
}

void Doku::initDoc(){
   doc = new DokuDoc();
}

void Doku::initView()
{ 
  ////////////////////////////////////////////////////////////////////
  // set the main widget here
  view = new DokuView(this,doc);
  setCentralWidget( view );
}

bool Doku::queryExit()
{
  int exit=QMessageBox::information(this,"Quit...","Really Quit?",QMessageBox::Ok,QMessageBox::Cancel);

    if(exit==1){
      return true;
    }
    else{
      return false;
    }
}

/////////////////////////////////////////////////////////////////////
// SLOT IMPLEMENTATION
/////////////////////////////////////////////////////////////////////


void Doku::slotFileNew()
{
  statusBar()->message("Creating new file...");

  // Wurde der Dauerauftrag veraendert ?
  if (doc->isModified())
   {
    QMessageBox modified_MessageBox("Dokumentenverwaltung","Ihre Dokumentenmappe wurde seit dem letzten Speichern gendert.\nMchten Sie vorher abspeichern?",
                       QMessageBox::Information, QMessageBox::Yes | QMessageBox::Default,
                       QMessageBox::No,QMessageBox::Cancel,this,"modified_MessageBox",TRUE,0);
    // Soll vorher gesichert werden?
    switch (modified_MessageBox.exec())
    {
     case QMessageBox::Yes : slotFileSave(); // ja -> sichern
                             doc->newDoc();
                             doc_menu->setItemEnabled(ID_DOC_INSERT,true);
                             doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
                             doc_menu->setItemEnabled(ID_DOC_DELETE,true);
                             break;
     case QMessageBox::No : doc->newDoc();
                            doc_menu->setItemEnabled(ID_DOC_INSERT,true);
                            doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
                            doc_menu->setItemEnabled(ID_DOC_DELETE,true);
                            break;
     case QMessageBox::Cancel : break;
    }


   } else {  doc->newDoc();
             doc_menu->setItemEnabled(ID_DOC_INSERT,true);
             doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
             doc_menu->setItemEnabled(ID_DOC_DELETE,true);
          }
  statusBar()->message(IDS_DEFAULT);
}

void Doku::slotFileOpen()
{
  statusBar()->message("Opening file...");

  QString fileName;

  // Wurde der Dauerauftrag veraendert ?
  if (doc->isModified())
   {
    QMessageBox modified_MessageBox("Dokumentenverwaltung","Ihre Dokumentenmappe wurde seit dem letzten Speichern gendert.\nMchten Sie vorher abspeichern?",
                       QMessageBox::Information, QMessageBox::Yes | QMessageBox::Default,
                       QMessageBox::No,QMessageBox::Cancel,this,"modified_MessageBox",TRUE,0);
    // Soll vorher gespeichert werden?
    switch (modified_MessageBox.exec())
    {
     case QMessageBox::Yes : slotFileSave(); // ja -> speichern
                             fileName = QFileDialog::getOpenFileName(0,"*.map",this);
                             if ( !fileName.isEmpty() )
                              {
                               if (doc->load( fileName )==false)
                                {
                                 QMessageBox loadfailed_MessageBox("Dokumentenverwaltung","Das Laden der Datei ist fehlgeschlagen.\nMglicherweise ist die Datei kaputt oder keine Dokumentenmappen-Datei.",
                                                                    QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                                                    0,0,this,"loadfailed_MessageBox",TRUE,0);
                                 loadfailed_MessageBox.exec();
                                }
                                else {
                                 QString message = "Loaded document: " + fileName;
                                 statusBar()->message( message, 2000 );
                                 doc_menu->setItemEnabled(ID_DOC_INSERT,true);
                                 doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
                                 doc_menu->setItemEnabled(ID_DOC_DELETE,true);
                                }

                              }
                              else { statusBar()->message( "Opening aborted", 2000 ); }
                             break;
     case QMessageBox::No : fileName = QFileDialog::getOpenFileName(0,"*.map",this);
                            if ( !fileName.isEmpty() )
                             {
                              if (doc->load( fileName )==false)
                               {
                                QMessageBox loadfailed_MessageBox("Dokumentenverwaltung","Das Laden der Datei ist fehlgeschlagen.\nMglicherweise ist die Datei kaputt oder keine Dokumentenmappen-Datei.",
                                                                    QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                                                    0,0,this,"loadfailed_MessageBox",TRUE,0);
                                loadfailed_MessageBox.exec();
                               }
                               else {
                                QString message = "Loaded document: " + fileName;
                                statusBar()->message( message, 2000 );
                                doc_menu->setItemEnabled(ID_DOC_INSERT,true);
                                doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
                                doc_menu->setItemEnabled(ID_DOC_DELETE,true);
                               }
                             }
                             else { statusBar()->message( "Opening aborted", 2000 ); }
                            break;
     case QMessageBox::Cancel : break;
    }
   }
 else
  {
   fileName = QFileDialog::getOpenFileName(0,"*.map",this);
   if ( !fileName.isEmpty() )
    {
     if (doc->load( fileName )==false)
      {
       QMessageBox loadfailed_MessageBox("Dokumentenverwaltung","Das Laden der Datei ist fehlgeschlagen.\nMglicherweise ist die Datei kaputt oder keine Dokumentenmappen-Datei.",
                                         QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                         0,0,this,"loadfailed_MessageBox",TRUE,0);
       loadfailed_MessageBox.exec();
      }
      else {
       QString message = "Loaded document: " + fileName;
       statusBar()->message( message, 2000 );
       doc_menu->setItemEnabled(ID_DOC_INSERT,true);
       doc_menu->setItemEnabled(ID_DOC_MODIFY,true);
       doc_menu->setItemEnabled(ID_DOC_DELETE,true);
      }

    }
   else { statusBar()->message( "Opening aborted", 2000 ); }
  }

}


void Doku::slotFileSave()
{
  statusBar()->message("Saving file...");

  if (doc->mappeExists())
   {
    if (doc->getName()=="unbenannt.map") slotFileSaveAs();
     else doc->save();
   }

  statusBar()->message(IDS_DEFAULT);
}

void Doku::slotFileSaveAs()
{
  statusBar()->message("Saving file under new filename...");

  if (doc->mappeExists())
   {

    QString fn = QFileDialog::getSaveFileName(0,"*.map",this);
    if ( !fn.isEmpty() ){
      if (fn.contains(".")==0) fn+=".map";
      {
       doc->saveAs( fn );
      }
    }
    else{  statusBar()->message( "Saving aborted", 2000 );  }
   }
  statusBar()->message(IDS_DEFAULT);
}

void Doku::slotFileClose()
{
  statusBar()->message("Closing file...");


  if (doc->isModified())
   {
    QMessageBox modified_MessageBox("Dokumentenverwaltung","Ihre Dokumentenmappe wurde seit dem letzten Speichern gendert.\nMchten Sie vorher abspeichern?",
                       QMessageBox::Information, QMessageBox::Yes | QMessageBox::Default,
                       QMessageBox::No,QMessageBox::Cancel,this,"modified_MessageBox",TRUE,0);
    switch (modified_MessageBox.exec())
    {
     case QMessageBox::Yes : slotFileSave();
                             doc->close();
                             doc_menu->setItemEnabled(ID_DOC_INSERT,false);
                             doc_menu->setItemEnabled(ID_DOC_MODIFY,false);
                             doc_menu->setItemEnabled(ID_DOC_DELETE,false);
                          break;
     case QMessageBox::No : doc->close();
                            doc_menu->setItemEnabled(ID_DOC_INSERT,false);
                            doc_menu->setItemEnabled(ID_DOC_MODIFY,false);
                            doc_menu->setItemEnabled(ID_DOC_DELETE,false);
                            break;
     case QMessageBox::Cancel : break;
    }


   } else { doc->close();
            doc_menu->setItemEnabled(ID_DOC_INSERT,false);
            doc_menu->setItemEnabled(ID_DOC_MODIFY,false);
            doc_menu->setItemEnabled(ID_DOC_DELETE,false);
          }





  statusBar()->message(IDS_DEFAULT);
}


void Doku::slotFileQuit()
{ 
  ///////////////////////////////////////////////////////////////////
  // exits the Application
  if(doc->isModified()){
    if(this->queryExit())
      {
	qApp->quit();
      }
    else{
      statusBar()->message(IDS_DEFAULT);
    }
  }
  else{
    qApp->quit();
  }
}

void Doku::slotEditCut()
{
  statusBar()->message("Cutting selection...");

  statusBar()->message(IDS_DEFAULT);
}

void Doku::slotEditCopy()
{
  statusBar()->message("Copying selection to Clipboard...");
  
  statusBar()->message(IDS_DEFAULT);
}

void Doku::slotEditPaste()
{
  statusBar()->message("Inserting Clipboard contents...");
  
  statusBar()->message(IDS_DEFAULT);
}


void Doku::slotViewToolBar()
{
  ///////////////////////////////////////////////////////////////////
  // turn Toolbar on or off
  
  if ( file_toolbar->isVisible() ) {
    file_toolbar->hide();
    view_menu->setItemChecked( ID_VIEW_TOOLBAR, false);
  } 
  else {
    file_toolbar->show();
    view_menu->setItemChecked( ID_VIEW_TOOLBAR, true );
  }  
  statusBar()->message(IDS_DEFAULT);

}

void Doku::slotViewStatusBar()
{
  ///////////////////////////////////////////////////////////////////
  //turn Statusbar on or off
  
  if ( statusBar()->isVisible() ) {
    statusBar()->hide();
    view_menu->setItemChecked( ID_VIEW_STATUSBAR, false );
  }
  else {
    statusBar()->show();
    view_menu->setItemChecked( ID_VIEW_STATUSBAR, true );
  }
  
  statusBar()->message(IDS_DEFAULT);
}


void Doku::slotDocInsert()
{
  statusBar()->message("Inserting document...");

  DlgWhatInsert dwhat;


  if (dwhat.exec())
  {
   if (dwhat.getType()=="Dokument")
    {
     DlgDokumentInsert ddok;
     if (ddok.exec())
     {
      if (doc->insertDokument(ddok.getVerfasser(),ddok.getTitel(),ddok.getSchluessel())==false)
      { QMessageBox insertfailed_MessageBox("Dokumentenverwaltung","Das Einfgen ist fehlgeschlagen.\nMglicherweise ist schon ein Dokument mit dem gleichen Schlssel vorhanden.",
                      QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                      0,0,this,"insertfailed_MessageBox",TRUE,0);
        insertfailed_MessageBox.exec(); }
     }
    }
   if (dwhat.getType()=="Formular")
    {
     DlgFormularInsert dfor;
     if (dfor.exec())
     {
      if (doc->insertFormular(dfor.getVerfasser(),dfor.getTitel(),dfor.getSchluessel(),
                          dfor.getGeprueft(), dfor.getUnterschriftKundeVorhanden(),
                          dfor.getFormvorschrift())==false)
       { QMessageBox insertfailed_MessageBox("Dokumentenverwaltung","Das Einfgen ist fehlgeschlagen.\nMglicherweise ist schon ein Dokument mit dem gleichen Schlssel vorhanden.",
                       QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                       0,0,this,"insertfailed_MessageBox",TRUE,0);
         insertfailed_MessageBox.exec(); }

     }

    }
   if (dwhat.getType()=="Vertrag")
    {
     DlgVertragInsert dver;
     if (dver.exec())
     {
      if (doc->insertVertrag(dver.getVerfasser(), dver.getTitel(),dver.getSchluessel(),
                         dver.getUnterschriftKundeVorhanden(), dver.getUnterschriftBankVorhanden(),
                         dver.getVertragsnummer(), dver.getVertragstext())==false)
       { QMessageBox insertfailed_MessageBox("Dokumentenverwaltung","Das Einfgen ist fehlgeschlagen.\nMglicherweise ist schon ein Dokument mit dem gleichen Schlssel vorhanden.",
                       QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                       0,0,this,"insertfailed_MessageBox",TRUE,0);
         insertfailed_MessageBox.exec(); }

     }

    }
   if (dwhat.getType()=="Dauerauftrag")
    {
     DlgDauerauftragInsert ddau;
     if (ddau.exec())
     {
      if (doc->insertDauerauftrag(ddau.getVerfasser(),ddau.getTitel(),ddau.getSchluessel(),
                              ddau.getGeprueft(), ddau.getUnterschriftKundeVorhanden(),
                              ddau.getFormvorschrift(), ddau.getBetrag(), ddau.getIntervall(),
                              ddau.getQuelle(), ddau.getZiel(), ddau.getBuchungstext())==false)
       { QMessageBox insertfailed_MessageBox("Dokumentenverwaltung","Das Einfgen ist fehlgeschlagen.\nMglicherweise ist schon ein Dokument mit dem gleichen Schlssel vorhanden.",
                       QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                       0,0,this,"insertfailed_MessageBox",TRUE,0);
         insertfailed_MessageBox.exec(); }

     }
    }
  }
  statusBar()->message(IDS_DEFAULT);
}




void Doku::slotDocModify()
{
  statusBar()->message("Modifying document...");

	CDokument* dok;

  QString s;
	QDateTime AltesErstellungsdatum;

	dok = view->getSelectedDokument();
  if (dok!=NULL)
   {
    AltesErstellungsdatum=dok->LiefereErstellungsdatum();

    if (dok->LiefereClassID()==Dokument)
     {
      DlgDokumentInsert ddok;
      ddok.setVerfasser(dynamic_cast<CDokument*>(dok)->LiefereVerfasser());
      ddok.setTitel(dynamic_cast<CDokument*>(dok)->LiefereTitel());
      ddok.setSchluessel(dynamic_cast<CDokument*>(dok)->LiefereSchluessel());
      if (ddok.exec())
      {
       if (doc->searchDokument(dok->LiefereSchluessel())!=NULL)
        {
         QMessageBox doublekeydok_MessageBox("Dokumentenverwaltung","Modifizieren fehlgeschlagen.\nEs existiert schon ein Dokument mit dem gleichen Schlssel.",
                                             QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                             0,0,this,"doublekeydok_MessageBox",TRUE,0);
         doublekeydok_MessageBox.exec();
        }
       else
        {
         doc->deleteDokument(dok->LiefereSchluessel());
         doc->insertDokument(ddok.getVerfasser(),ddok.getTitel(),ddok.getSchluessel());
         dok=doc->searchDokument(ddok.getSchluessel());
        }
      }
     }
    if (dok->LiefereClassID()==Formular)
     {
      DlgFormularInsert dfor;
      dfor.setVerfasser(dynamic_cast<CFormular*>(dok)->LiefereVerfasser());
      dfor.setTitel(dynamic_cast<CFormular*>(dok)->LiefereTitel());
      dfor.setSchluessel(dynamic_cast<CFormular*>(dok)->LiefereSchluessel());
      dfor.setGeprueft(dynamic_cast<CFormular*>(dok)->LieferePruefzustand());
      dfor.setUnterschriftKundeVorhanden(dynamic_cast<CFormular*>(dok)->LiefereUnterschriftKundeVorhanden());
      dfor.setFormvorschrift(dynamic_cast<CFormular*>(dok)->LiefereFormvorschrift());
      if (dfor.exec())
      {
       if (doc->searchDokument(dok->LiefereSchluessel())!=NULL)
        {
         QMessageBox doublekeyfor_MessageBox("Dokumentenverwaltung","Modifizieren fehlgeschlagen.\nEs existiert schon ein Formular mit dem gleichen Schlssel.",
                                             QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                             0,0,this,"doublekeyfor_MessageBox",TRUE,0);
         doublekeyfor_MessageBox.exec();
        }
       else
        {
         doc->deleteDokument(dok->LiefereSchluessel());
         doc->insertFormular(dfor.getVerfasser(),dfor.getTitel(),dfor.getSchluessel(),
                             dfor.getGeprueft(), dfor.getUnterschriftKundeVorhanden(),
                           dfor.getFormvorschrift());
         dok=doc->searchDokument(dfor.getSchluessel());
        }
      }

     }
    if (dok->LiefereClassID()==Vertrag)
     {
      DlgVertragInsert dver;
      dver.setVerfasser(dynamic_cast<CVertrag*>(dok)->LiefereVerfasser());
      dver.setTitel(dynamic_cast<CVertrag*>(dok)->LiefereTitel());
      dver.setSchluessel(dynamic_cast<CVertrag*>(dok)->LiefereSchluessel());
      dver.setVertragsnummer(dynamic_cast<CVertrag*>(dok)->LiefereVertragsnummer());
      dver.setUnterschriftBankVorhanden(dynamic_cast<CVertrag*>(dok)->LiefereUnterschriftBankVorhanden());
      dver.setUnterschriftKundeVorhanden(dynamic_cast<CVertrag*>(dok)->LiefereUnterschriftKundeVorhanden());
      dver.setVertragstext(dynamic_cast<CVertrag*>(dok)->LiefereVertragstext());
      if (dver.exec())
      {
       if (doc->searchDokument(dok->LiefereSchluessel())!=NULL)
        {
         QMessageBox doublekeyver_MessageBox("Dokumentenverwaltung","Modifizieren fehlgeschlagen.\nEs existiert schon einen Vertrag mit dem gleichen Schlssel.",
                                             QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                             0,0,this,"doublekeyver_MessageBox",TRUE,0);
         doublekeyver_MessageBox.exec();
        }
       else
        {
         doc->deleteDokument(dok->LiefereSchluessel());
         doc->insertVertrag(dver.getVerfasser(), dver.getTitel(),dver.getSchluessel(),
                            dver.getUnterschriftKundeVorhanden(), dver.getUnterschriftBankVorhanden(),
                            dver.getVertragsnummer(), dver.getVertragstext());
         dok=doc->searchDokument(dver.getSchluessel());
        }
      }
     }
    if (dok->LiefereClassID()==Dauerauftrag)
     {
      DlgDauerauftragInsert ddau;
      ddau.setVerfasser(dynamic_cast<CDauerauftrag*>(dok)->LiefereVerfasser());
      ddau.setTitel(dynamic_cast<CDauerauftrag*>(dok)->LiefereTitel());
      ddau.setSchluessel(dynamic_cast<CDauerauftrag*>(dok)->LiefereSchluessel());
      ddau.setGeprueft(dynamic_cast<CDauerauftrag*>(dok)->LieferePruefzustand());
      ddau.setUnterschriftKundeVorhanden(dynamic_cast<CDauerauftrag*>(dok)->LiefereUnterschriftKundeVorhanden());
      ddau.setFormvorschrift(dynamic_cast<CDauerauftrag*>(dok)->LiefereFormvorschrift());
      s.setNum(dynamic_cast<CDauerauftrag*>(dok)->LiefereBetrag());
      ddau.setBetrag(s);
      s.setNum(dynamic_cast<CDauerauftrag*>(dok)->LiefereIntervall()/86400);
      ddau.setIntervall(s);
      ddau.setQuelle(dynamic_cast<CDauerauftrag*>(dok)->LiefereQuelle());
      ddau.setZiel(dynamic_cast<CDauerauftrag*>(dok)->LiefereZiel());
      ddau.setBuchungstext(dynamic_cast<CDauerauftrag*>(dok)->LiefereBuchungstext());
      if (ddau.exec())
      {
       if (doc->searchDokument(dok->LiefereSchluessel())!=NULL)
        {
         QMessageBox doublekeydau_MessageBox("Dokumentenverwaltung","Modifizieren fehlgeschlagen.\nEs existiert schon einen Dauerauftrag mit dem gleichen Schlssel.",
                                             QMessageBox::Information, QMessageBox::Ok | QMessageBox::Default,
                                             0,0,this,"doublekeydau_MessageBox",TRUE,0);
         doublekeydau_MessageBox.exec();
        }
       else
        {
         doc->deleteDokument(dok->LiefereSchluessel());
         doc->insertDauerauftrag(ddau.getVerfasser(),ddau.getTitel(),ddau.getSchluessel(),
                                 ddau.getGeprueft(), ddau.getUnterschriftKundeVorhanden(),
                                 ddau.getFormvorschrift(), ddau.getBetrag(), ddau.getIntervall(),
                                 ddau.getQuelle(), ddau.getZiel(), ddau.getBuchungstext());
         dok=doc->searchDokument(ddau.getSchluessel());
        }
      }
     }

    dok->AendereErstellungsdatum(AltesErstellungsdatum);
    view->setSelectedDokument(dok);
   }

  statusBar()->message(IDS_DEFAULT);
}


void Doku::slotDocDelete()
{
  statusBar()->message("Deleting document...");

	CDokument* dok;

	dok = view->getSelectedDokument();
  if (dok!=NULL) doc->deleteDokument(dok->LiefereSchluessel());

  statusBar()->message(IDS_DEFAULT);
}


void Doku::slotHelpAbout(){
  QMessageBox::about(this,"About...", IDS_APP_ABOUT "\n(c) 1999 by Stephan Uhlmann\n<suhlmann@gmx.de>");
}

void Doku::slotStatusHelpMsg(const char *text)
{
  ///////////////////////////////////////////////////////////////////
  // change status message of whole statusbar temporary (text, msec)
  statusBar()->message(text, 2000);
}

void Doku::statusCallback(int id_){
  switch (id_) {
    
  case ID_FILE_NEW        :  slotStatusHelpMsg("Creates a new document");break;
  case ID_FILE_OPEN       :  slotStatusHelpMsg("Opens an existing document");break;
  case ID_FILE_SAVE       :  slotStatusHelpMsg("Save the actual document");break;
  case ID_FILE_SAVE_AS    :  slotStatusHelpMsg("Save the actual document");break;
  case ID_FILE_CLOSE      :  slotStatusHelpMsg("Closes the actual file");break;
  case ID_FILE_QUIT       :  slotStatusHelpMsg("Exits the program");break;
  case ID_EDIT_CUT        :  slotStatusHelpMsg("Cuts the selected section and puts it to the clipboard")
			      ;break;
  case ID_EDIT_COPY       :  slotStatusHelpMsg("Copys the selected section to the clipboard");break;
  case ID_EDIT_PASTE      :  slotStatusHelpMsg("Pastes the clipboard contents to actual position");break;
  case ID_EDIT_SELECT_ALL :  slotStatusHelpMsg("Selects the whole document contents");break;
  case ID_VIEW_TOOLBAR    :  slotStatusHelpMsg("Enables / disables the actual Toolbar");break;
  case ID_VIEW_STATUSBAR  :  slotStatusHelpMsg("Enables / disables the Statusbar");break;   
  case ID_DOC_INSERT      :  slotStatusHelpMsg("Insert document");break;
  case ID_DOC_MODIFY      :  slotStatusHelpMsg("Modify document");break;
  case ID_DOC_DELETE      :  slotStatusHelpMsg("Delete document");break;
  case ID_HELP_ABOUT      :  slotStatusHelpMsg("Shows an aboutbox");break;
  }
}



























