/***************************************************************************
                          dokuview.cpp  -  Implementation Klasse DokuView (View)
                             -------------------                                         
    begin                : Wed Aug  4 17:32:35 MEST 1999
                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include <qpixmap.h>
#include <qprogressbar.h>
#include <qdatetime.h>
#include "dokuview.h"



DokuView::DokuView(QWidget *parent,DokuDoc* mydoc) : QWidget(parent) {

  doc=mydoc;

  l_groupbox = new QGroupBox(this,"l_groupbox");
  QWhatsThis::add(l_groupbox,"Hier wird Ihre Dokumentenmappe in Listenform angezeigt.");

  r_groupbox = new QGroupBox(this,"r_groupbox");
  QWhatsThis::add(r_groupbox,"Hier wird der Inhalt eines aktuellen gewhlten Dokuments angezeigt.");

  mappe_listview = new QListView(l_groupbox,"mappe_listview");
  mappe_listview->setRootIsDecorated( true );
  mappe_listview->addColumn("Dokumentenmappe");
  dokument_listviewitem = new QListViewItem(mappe_listview,"Dokumente");
  formular_listviewitem = new QListViewItem(mappe_listview,"Formulare");
  vertrag_listviewitem = new QListViewItem(mappe_listview,"Vertrge");
  dauerauftrag_listviewitem = new QListViewItem(mappe_listview,"Dauerauftrge");
  mappe_listview->setSelected(dauerauftrag_listviewitem, true);
  mappe_listview->hide();

  viewdlg = new DlgFormularShow(r_groupbox);
  viewdlg->hide();

  defaultdlg = new QWidget(r_groupbox);
  defaultdlg->setGeometry(5,5,r_groupbox->width()-10,r_groupbox->height()-10);
  defaultdlg->setMinimumSize(0,0);
  defaultdlg->setBackgroundColor(QColor(255,255,255));

  defaultdlgpm = new QWidget(defaultdlg);
  defaultdlgpm->setGeometry(20,100,376,157);
  defaultdlgpm->setMinimumSize(0,0);
  defaultdlgpm->setBackgroundColor(QColor(255,255,255));

  QPixmap welcomepm;
  welcomepm.load("pics/dokumain.bmp");
  defaultdlgpm->setBackgroundPixmap(welcomepm);

  defaultdlg->show();


  connect(mappe_listview,SIGNAL(selectionChanged()),this,SLOT(slotSelectionChanged()));

}

DokuView::~DokuView(){
}

// update the view
void DokuView::slotDocumentChanged(){

unsigned int i,j;
QListViewItem* it;
CDokument* dok;


// clean up then rebuild listsviews
// rebuild the ListViewItem to CDokument Dictionary also
 dictItem2Dok.clear();
 for (i=0;i<dokument_listviewitem_list.size();i++)
  delete dokument_listviewitem_list[i];
 dokument_listviewitem_list.resize(0);
 for (i=0;i<formular_listviewitem_list.size();i++)
  delete formular_listviewitem_list[i];
 formular_listviewitem_list.resize(0);
 for (i=0;i<vertrag_listviewitem_list.size();i++)
  delete vertrag_listviewitem_list[i];
 vertrag_listviewitem_list.resize(0);
 for (i=0;i<dauerauftrag_listviewitem_list.size();i++)
  delete dauerauftrag_listviewitem_list[i];
 dauerauftrag_listviewitem_list.resize(0);

 if (doc->mappeExists())
  {
   mappe_listview->setColumnText(0,doc->getName());
   for (i=0;i<doc->LiefereAnzahl();i++)
    {
      dok=doc->LiefereDokumentNumber(i);
      switch(dok->LiefereClassID())
      {
       case Dokument : it=new QListViewItem(dokument_listviewitem);
                       j=dokument_listviewitem_list.size();
                       dokument_listviewitem_list.resize(j+1);
                       it->setText(0,dok->LiefereTitel());
                       dokument_listviewitem_list[j]=it;
                       dictItem2Dok.insert(it,dok);
                       break;
       case Formular : it=new QListViewItem(formular_listviewitem);
                       j=formular_listviewitem_list.size();
                       formular_listviewitem_list.resize(j+1);
                       it->setText(0,dok->LiefereTitel());
                       formular_listviewitem_list[j]=it;
                       dictItem2Dok.insert(it,dok);
                       break;
       case Vertrag : it=new QListViewItem(vertrag_listviewitem);
                      j=vertrag_listviewitem_list.size();
                      vertrag_listviewitem_list.resize(j+1);
                      it->setText(0,dok->LiefereTitel());
                      vertrag_listviewitem_list[j]=it;
                      dictItem2Dok.insert(it,dok);
                      break;
       case Dauerauftrag : it=new QListViewItem(dauerauftrag_listviewitem);
                           j=dauerauftrag_listviewitem_list.size();
                           dauerauftrag_listviewitem_list.resize(j+1);
                           it->setText(0,dok->LiefereTitel());
                           dauerauftrag_listviewitem_list[j]=it;
                           dictItem2Dok.insert(it,dok);
       }
    }
   mappe_listview->show();
  }
  else mappe_listview->hide();

// now the right side
 slotSelectionChanged();

}


void DokuView::slotSelectionChanged(){
 unsigned int i;
 bool viewdlgshow;
 CDokument* dok;


 viewdlgshow=false;


 for (i=0;i<dokument_listviewitem_list.size();i++)
  if (dokument_listviewitem_list[i]->isSelected())
   {
    delete viewdlg;
    viewdlg = new DlgDokumentShow(r_groupbox);
    dok = dictItem2Dok.find(dokument_listviewitem_list[i]);
    dynamic_cast<DlgDokumentShow*>(viewdlg)->setVerfasser(dynamic_cast<CDokument*>(dok)->LiefereVerfasser());
    dynamic_cast<DlgDokumentShow*>(viewdlg)->setTitel(dynamic_cast<CDokument*>(dok)->LiefereTitel());
    dynamic_cast<DlgDokumentShow*>(viewdlg)->setSchluessel(dynamic_cast<CDokument*>(dok)->LiefereSchluessel());
    dynamic_cast<DlgDokumentShow*>(viewdlg)->setErstellungsdatum(dynamic_cast<CDokument*>(dok)->LiefereErstellungsdatum());
    viewdlgshow=true;
   }


 for (i=0;i<formular_listviewitem_list.size();i++)
  if (formular_listviewitem_list[i]->isSelected())
   {
    delete viewdlg;
    viewdlg = new DlgFormularShow(r_groupbox);
    dok = dictItem2Dok.find(formular_listviewitem_list[i]);
    dynamic_cast<DlgFormularShow*>(viewdlg)->setVerfasser(dynamic_cast<CFormular*>(dok)->LiefereVerfasser());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setTitel(dynamic_cast<CFormular*>(dok)->LiefereTitel());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setSchluessel(dynamic_cast<CFormular*>(dok)->LiefereSchluessel());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setErstellungsdatum(dynamic_cast<CFormular*>(dok)->LiefereErstellungsdatum());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setGeprueft(dynamic_cast<CFormular*>(dok)->LieferePruefzustand());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setUnterschriftKundeVorhanden(dynamic_cast<CFormular*>(dok)->LiefereUnterschriftKundeVorhanden());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setFormvorschrift(dynamic_cast<CFormular*>(dok)->LiefereFormvorschrift());
    dynamic_cast<DlgFormularShow*>(viewdlg)->setAenderungsdatum(dynamic_cast<CFormular*>(dok)->LiefereAenderungsdatum());
    viewdlgshow=true;
   }


 for (i=0;i<vertrag_listviewitem_list.size();i++)
  if (vertrag_listviewitem_list[i]->isSelected())
   {
    delete viewdlg;
    viewdlg = new DlgVertragShow(r_groupbox);
    dok = dictItem2Dok.find(vertrag_listviewitem_list[i]);
    dynamic_cast<DlgVertragShow*>(viewdlg)->setVerfasser(dynamic_cast<CVertrag*>(dok)->LiefereVerfasser());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setTitel(dynamic_cast<CVertrag*>(dok)->LiefereTitel());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setSchluessel(dynamic_cast<CVertrag*>(dok)->LiefereSchluessel());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setErstellungsdatum(dynamic_cast<CVertrag*>(dok)->LiefereErstellungsdatum());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setVertragsnummer(dynamic_cast<CVertrag*>(dok)->LiefereVertragsnummer());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setUnterschriftBankVorhanden(dynamic_cast<CVertrag*>(dok)->LiefereUnterschriftBankVorhanden());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setUnterschriftKundeVorhanden(dynamic_cast<CVertrag*>(dok)->LiefereUnterschriftKundeVorhanden());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setVertragstext(dynamic_cast<CVertrag*>(dok)->LiefereVertragstext());
    dynamic_cast<DlgVertragShow*>(viewdlg)->setAenderungsdatum(dynamic_cast<CVertrag*>(dok)->LiefereAenderungsdatum());
    viewdlgshow=true;
   }


 for (i=0;i<dauerauftrag_listviewitem_list.size();i++)
  if (dauerauftrag_listviewitem_list[i]->isSelected())
   {
    delete viewdlg;
    viewdlg = new DlgDauerauftragShow(r_groupbox);
    dok = dictItem2Dok.find(dauerauftrag_listviewitem_list[i]);
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setVerfasser(dynamic_cast<CDauerauftrag*>(dok)->LiefereVerfasser());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setTitel(dynamic_cast<CDauerauftrag*>(dok)->LiefereTitel());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setSchluessel(dynamic_cast<CDauerauftrag*>(dok)->LiefereSchluessel());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setErstellungsdatum(dynamic_cast<CDauerauftrag*>(dok)->LiefereErstellungsdatum());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setGeprueft(dynamic_cast<CDauerauftrag*>(dok)->LieferePruefzustand());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setUnterschriftKundeVorhanden(dynamic_cast<CDauerauftrag*>(dok)->LiefereUnterschriftKundeVorhanden());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setFormvorschrift(dynamic_cast<CDauerauftrag*>(dok)->LiefereFormvorschrift());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setAenderungsdatum(dynamic_cast<CDauerauftrag*>(dok)->LiefereAenderungsdatum());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setBetrag(dynamic_cast<CDauerauftrag*>(dok)->LiefereBetrag());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setIntervall(dynamic_cast<CDauerauftrag*>(dok)->LiefereIntervall());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setQuelle(dynamic_cast<CDauerauftrag*>(dok)->LiefereQuelle());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setZiel(dynamic_cast<CDauerauftrag*>(dok)->LiefereZiel());
    dynamic_cast<DlgDauerauftragShow*>(viewdlg)->setBuchungstext(dynamic_cast<CDauerauftrag*>(dok)->LiefereBuchungstext());
    viewdlgshow=true;
   }

 if (viewdlgshow) { viewdlg->show(); defaultdlg->hide();}
  else { viewdlg->hide(); defaultdlg->show(); }

}



void DokuView::resizeEvent( QResizeEvent * )
{
 l_groupbox->setGeometry(0,0,this->width()/3,this->height());
 mappe_listview->setGeometry(0,0,l_groupbox->width(),l_groupbox->height());
 mappe_listview->setColumnWidth(0,mappe_listview->width());
 r_groupbox->setGeometry(l_groupbox->width(),0,this->width()-l_groupbox->width(),this->height());
 defaultdlg->setGeometry(5,5,r_groupbox->width()-10,r_groupbox->height()-10);
}


CDokument* DokuView::getSelectedDokument(){
 unsigned int i;

 CDokument* dok;

 dok=NULL;

 for (i=0;i<dokument_listviewitem_list.size();i++)
  if (dokument_listviewitem_list[i]->isSelected())
   {
    dok = dictItem2Dok.find(dokument_listviewitem_list[i]);
   }

 for (i=0;i<formular_listviewitem_list.size();i++)
  if (formular_listviewitem_list[i]->isSelected())
   {
    dok = dictItem2Dok.find(formular_listviewitem_list[i]);
   }

 for (i=0;i<vertrag_listviewitem_list.size();i++)
  if (vertrag_listviewitem_list[i]->isSelected())
   {
    dok = dictItem2Dok.find(vertrag_listviewitem_list[i]);
   }

 for (i=0;i<dauerauftrag_listviewitem_list.size();i++)
  if (dauerauftrag_listviewitem_list[i]->isSelected())
   {
    dok = dictItem2Dok.find(dauerauftrag_listviewitem_list[i]);
   }

 return dok;
}

void DokuView::setSelectedDokument(CDokument* dok){
 unsigned int i;

 for (i=0;i<dokument_listviewitem_list.size();i++)
  if (dictItem2Dok.find(dokument_listviewitem_list[i])==dok)
   {
    mappe_listview->setSelected(dokument_listviewitem_list[i],true);
   }

 for (i=0;i<formular_listviewitem_list.size();i++)
  if (dictItem2Dok.find(formular_listviewitem_list[i])==dok)
   {
    mappe_listview->setSelected(formular_listviewitem_list[i],true);
   }

 for (i=0;i<vertrag_listviewitem_list.size();i++)
  if (dictItem2Dok.find(vertrag_listviewitem_list[i])==dok)
   {
    mappe_listview->setSelected(vertrag_listviewitem_list[i],true);
   }

 for (i=0;i<dauerauftrag_listviewitem_list.size();i++)
  if (dictItem2Dok.find(dauerauftrag_listviewitem_list[i])==dok)
   {
    mappe_listview->setSelected(dauerauftrag_listviewitem_list[i],true);
   }

}



void DokuView::slotDoProgressBar()
{
 QProgressBar pb(NULL);
 QTime t;
 int i,j;

 pb.setCaption("Saving...");
 pb.setGeometry(20,50,200,20);
 pb.show();
 for (i=0;i<=100;i++)
 {
  pb.setProgress(i);
  t=t.currentTime();
  j=t.msec();
  while (((t.msec() - j ) >=0 ) && ((t.msec() - j ) < 2)) {t=t.currentTime(); }
 }
}










