/***************************************************************************
                          menge.cc  -  Implementation Klasse CDokumentenmenge
                             -------------------                                         
    begin                : Wed Aug 4 1999                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "dokument.h"  /* Import Klasse CDokument */
#include "formular.h"  /* Import Klasse CFormular */
#include "vertrag.h"   /* Import Klasse CVertrag */
#include "dauerauf.h"  /* Import Klasse CDauerauftrag */
#include "menge.h"     /* Export des Moduls */


/* Konstruktor */
CDokumentenmenge::CDokumentenmenge()
{
 Anzahl=0;
 first=new TElement;
 first->Objekt=NULL;
 first->next=NULL;
}

/* Destruktor */
CDokumentenmenge::~CDokumentenmenge()
{
 Free();
}

/* generiert eine neue Dokumentenmenge und gibt einen Zeiger darauf zurueck */
CDokumentenmenge* CDokumentenmenge::Generate()
{
 CDokumentenmenge* dm;
 
 dm=new CDokumentenmenge;
 return dm;
}

/* gibt eine Dokumentenmenge frei */
void CDokumentenmenge::Free()
{
 unsigned int i;
 TElement* p;
 TElement* q;

 if (ClassInvariant()==FALSE) return; 

 p=first;

 for (i=1;i<=Anzahl;i++)
 {
  p->Objekt->Free();
  q=p->next;
  delete p;
  p=q;
 }
 
 Anzahl=MAX_ORDINAL;
 first=NULL;
}

/* ueberprueft die Klasseninvarianz des Objekts */
bool CDokumentenmenge::ClassInvariant() const
{
 unsigned int i;
 TElement* p;

 if (LiefereAnzahl()==MAX_ORDINAL) return FALSE;
 p=first;
 for (i=1;i<LiefereAnzahl();i++)
 {
  if (p->Objekt->ClassInvariant()==FALSE) return FALSE;
  p=p->next;
 }

 return TRUE;
}

/* kopiert in die aktuelle Dokumentenmenge die Dokumentenmenge src */
bool CDokumentenmenge::Copy(CDokumentenmenge* src)
{
 unsigned int i;
 TElement* p;

 if (src->ClassInvariant()==FALSE) return FALSE;
 Free();

 Anzahl=0;
 first=new TElement;
 first->Objekt=NULL;
 first->next=NULL;

 p=src->first;
 for (i=1;i<=src->LiefereAnzahl();i++)
 {
  EinfuegeDokument(p->Objekt);
  p=p->next;
 }

 return TRUE;
}

/* vergleicht zwei Dokumentenmengen miteinander */
bool CDokumentenmenge::EqualValue(CDokumentenmenge* src) const
{
 unsigned int i;
 TElement* p;
 TElement* q;


 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 if (LiefereAnzahl()!=src->LiefereAnzahl()) return FALSE;

 p=first;
 q=src->first;

 for (i=1;i<=Anzahl;i++)
 {
  if (p->Objekt->LiefereClassID()!=q->Objekt->LiefereClassID()) return FALSE;
  if (p->Objekt->EqualValue(q->Objekt)==FALSE) return FALSE;
  p=p->next;
  q=q->next;
 }

 return TRUE;
}

/* gibt die Anzahl der Dokumente in der Dokumentenmenge zurueck */
unsigned int CDokumentenmenge::LiefereAnzahl() const
{
 return Anzahl;
}

/* fuegt ein Dokument in die Dokumentenmenge ein */
bool CDokumentenmenge::EinfuegeDokument(CDokument* src)
{
 unsigned int i;
 TElement* p;

 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 p=first;
 for (i=1;i<=Anzahl;i++)
  { p=p->next; }

 p->Objekt=src->Generate();
 p->Objekt->Copy(src);

 p->next=new TElement;
 p=p->next;
 p->Objekt=NULL;
 p->next=NULL;
 Anzahl++;

 return TRUE;
}

/* loescht ein Dokument aus der Dokumentenmenge */
bool CDokumentenmenge::LoescheDokument(QString Schluessel)
{
 unsigned int i;
 TElement* p;
 TElement* q;

 if (ClassInvariant()==FALSE) return FALSE;

 if (DokumentInMenge(Schluessel)==FALSE) return FALSE;

 if (strcmp(first->Objekt->LiefereSchluessel(),Schluessel)==0)
 {
  p=first->next;
  first->Objekt->Free();
  delete first;
  first=p;
  Anzahl--;
  return TRUE;
 }

 p=first;
 q=first;
 for (i=1;i<=LiefereAnzahl();i++)
 {
  if (strcmp(p->Objekt->LiefereSchluessel(),Schluessel)==0)
   {
    q->next=p->next;
    p->Objekt->Free();
    delete p;
    Anzahl--;
    p=q;
    return TRUE;
   }
  q=p;
  p=p->next;
 }

 return FALSE;
}

/* Sucht ein Dokument in der Dokumentenmenge und gibt das entsprechende Element zurueck */
CDokumentenmenge::TElement* CDokumentenmenge::SucheDokument(QString Schluessel) const
{
 unsigned int i;
 TElement* p;

 if (ClassInvariant()==FALSE) return NULL;

 p=first;
 for (i=1;i<=Anzahl;i++)
  { if (strcmp(p->Objekt->LiefereSchluessel(),Schluessel)==0) return p;
    p=p->next; }

 return NULL;
}

/* prueft ob das Dokument in der Dokumentenmenge enthalten ist */
bool CDokumentenmenge::DokumentInMenge(QString Schluessel) const
{
 unsigned int i;
 TElement* p;

 if (ClassInvariant()==FALSE) return FALSE;

 p=first;
 for (i=1;i<=Anzahl;i++)
  { if (strcmp(p->Objekt->LiefereSchluessel(),Schluessel)==0) return TRUE;
    p=p->next; }

 return FALSE;
}

/* gibt das erste Element der Dokumentenmenge zurueck */
CDokumentenmenge::TElement* CDokumentenmenge::LiefereErstes()
{
 return first;
}



bool CDokumentenmenge::readData(QDataStream* stream)
{
 unsigned int i;
 TElement* p;
 TClassID id;
 int temp;
 bool b=true;

 *stream >> Anzahl;
 if (Anzahl>100) return false;
 p = first;
 for (i=1;i<=Anzahl;i++)
  {
   *stream >> temp;
   id = (TClassID)temp;
   switch (id)
   {
    case Dokument : p->Objekt = new CDokument;
                    p->next=new TElement;
                    p->next->Objekt=NULL;
                    p->next->next=NULL;
                    dynamic_cast<CDokument*>(p->Objekt)->readData(stream);
                    break;
    case Formular : p->Objekt = new CFormular;
                    p->next=new TElement;
                    p->next->Objekt=NULL;
                    p->next->next=NULL;
                    dynamic_cast<CFormular*>(p->Objekt)->readData(stream);
                    break;
    case Vertrag : p->Objekt = new CVertrag;
                   p->next=new TElement;
                   p->next->Objekt=NULL;
                   p->next->next=NULL;
                   dynamic_cast<CVertrag*>(p->Objekt)->readData(stream);
                   break;
    case Dauerauftrag : p->Objekt = new CDauerauftrag;
                        p->next=new TElement;
                        p->next->Objekt=NULL;
                        p->next->next=NULL;
                        dynamic_cast<CDauerauftrag*>(p->Objekt)->readData(stream);
                        break;
   }
   p=p->next;
  }

 return b;
}

bool CDokumentenmenge::writeData(QDataStream* stream) const
{
 unsigned int i;
 TElement* p;
 bool b=true;

 *stream << Anzahl;
 p=first;
 for (i=1;i<=Anzahl;i++)
  {
   *stream << (int)(p->Objekt->LiefereClassID());
   switch (p->Objekt->LiefereClassID())
   {
    case Dokument: dynamic_cast<CDokument*>(p->Objekt)->writeData(stream);break;
    case Formular: dynamic_cast<CFormular*>(p->Objekt)->writeData(stream);break;
    case Vertrag: dynamic_cast<CVertrag*>(p->Objekt)->writeData(stream);break;
    case Dauerauftrag: dynamic_cast<CDauerauftrag*>(p->Objekt)->writeData(stream);break;
   }
   p=p->next;
  }
 return b;
}








