/***************************************************************************
                          vertrag.cc  -  Implementation Klasse CVertrag
                             -------------------                                         
    begin                : Wed Aug 4 1999                                           
    copyright            : (C) 1999 by Stephan Uhlmann                         
    email                : suhlmann@gmx.de                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "dokument.h"      /* Import Klasse CDokument */
#include "vertrag.h"       /* Export des Moduls */

/* Konstruktor */
CVertrag::CVertrag()
{
 Vertragsnummer="";
 UnterschriftBankVorhanden=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Vertragstext="";
 Aenderungsdatum=LiefereErstellungsdatum();
 AendereClassID(Vertrag);
}

/* Destruktor */
CVertrag::~CVertrag()
{
 Vertragsnummer="";
 UnterschriftBankVorhanden=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Vertragstext="";
 Aenderungsdatum.setTime_t(0);
}

/* generiert ein Objekt des Typs CVertrag und gibt einen Zeiger darauf zurueck */
CDokument* CVertrag::Generate() const
{
 CVertrag* v;
 
 v=new CVertrag;
 return v;
}

/* gibt ein Objekt des Typs CVertrag wieder frei */
void CVertrag::Free()
{
 if (ClassInvariant()==FALSE) return;
 CDokument::Free();
 Vertragsnummer="";
 UnterschriftBankVorhanden=FALSE;
 UnterschriftKundeVorhanden=FALSE;
 Vertragstext="";
 Aenderungsdatum.setTime_t(0);
}

/* prueft die Klasseninvarianz des Objekts */
bool CVertrag::ClassInvariant() const
{
 if ((CDokument::ClassInvariant()) &&
     (LiefereErstellungsdatum() <= LiefereAenderungsdatum()) &&
     (LiefereAenderungsdatum() <= LiefereSystemdatum()) &&
     (ZulaessigerVertrag(Vertragstext)))
      return TRUE;
 else return FALSE;

}

/* kopiert den Vertrag src in den aktuellen Vertrag */
bool CVertrag::Copy(CDokument* src)
{
 CVertrag* v;

 if (src->ClassInvariant()==FALSE) return FALSE;
 v=dynamic_cast<CVertrag*>(src);
 InitVertrag(v->LiefereVerfasser(),v->LiefereTitel(),v->LiefereSchluessel(),v->LiefereVertragsnummer(),
             v->LiefereUnterschriftBankVorhanden(),v->LiefereUnterschriftKundeVorhanden(),
	     v->LiefereVertragstext());
 AendereErstellungsdatum(v->LiefereErstellungsdatum());
 Aenderungsdatum=v->LiefereAenderungsdatum();
 return TRUE;
}

/* vergleicht zwei Vertraege miteinander */
bool CVertrag::EqualValue(CDokument* src) const
{
 CVertrag* v;

 if (ClassInvariant()==FALSE) return FALSE;
 if (src->ClassInvariant()==FALSE) return FALSE;

 v=dynamic_cast<CVertrag*>(src);
 if (CDokument::EqualValue(v)==FALSE) return FALSE;
 if (strcmp(LiefereVertragsnummer(),v->LiefereVertragsnummer())!=0) return FALSE;
 if (LiefereUnterschriftBankVorhanden()!=v->LiefereUnterschriftBankVorhanden()) return FALSE;
 if (LiefereUnterschriftKundeVorhanden()!=v->LiefereUnterschriftKundeVorhanden()) return FALSE;
 if (strcmp(LiefereVertragstext(),v->LiefereVertragstext())!=0) return FALSE;
 if (LiefereErstellungsdatum()!=v->LiefereErstellungsdatum()) return FALSE;
 if (LiefereAenderungsdatum()!=v->LiefereAenderungsdatum()) return FALSE;
 return TRUE;
}

/* initialisiert einen existierenden Vertrag mit den gegebenen Werten */
bool CVertrag::InitVertrag(QString NVerfasser,
                           QString NTitel,
      	                   QString NSchluessel,
                  				 QString NVertragsnummer,
		                       bool NUnterschriftBankVorhanden,
         	                 bool NUnterschriftKundeVorhanden,
		                       QString NVertragstext)
{
 /* Da Free() virtual ist, wird in InitDokument CVertrag::Free() aufgerufen */
 InitDokument(NVerfasser,NTitel,NSchluessel);
 Vertragsnummer=NVertragsnummer;
 UnterschriftBankVorhanden=NUnterschriftBankVorhanden;
 UnterschriftKundeVorhanden=NUnterschriftKundeVorhanden;
 Vertragstext=NVertragstext;
 Aenderungsdatum=LiefereErstellungsdatum();
 return TRUE;
}

/* liefert die Vertragsnummer */
QString CVertrag::LiefereVertragsnummer() const
{
 return Vertragsnummer;
}

/* gibt zurueck ob die Unterschrift der Bank vorhanden ist */
bool CVertrag::LiefereUnterschriftBankVorhanden() const
{
 return UnterschriftBankVorhanden;
}

/* aendert die Tatsache ob die Bank unterschrieben hat */
void CVertrag::AendereUnterschriftBankVorhanden(bool NUnterschriftBankVorhanden)
{
 UnterschriftBankVorhanden=NUnterschriftBankVorhanden;
}

/* gibt zurueck ob der Kunde unterschrieben hat */
bool CVertrag::LiefereUnterschriftKundeVorhanden() const
{
 return UnterschriftKundeVorhanden;
}

/* aendert die Tatsache ob der Kunde unterschrieben hat */
void CVertrag::AendereUnterschriftKundeVorhanden(bool NUnterschriftKundeVorhanden)
{
 UnterschriftKundeVorhanden=NUnterschriftKundeVorhanden;
}

/* gibt den Vertragstext zurueck */
QString CVertrag::LiefereVertragstext() const
{
 return Vertragstext;
}

/* aendert den Vertragstext */
void CVertrag::AendereVertragstext(QString NVertragstext)
{
 Vertragstext=NVertragstext;
}

/* gibt das Datum der letzten Aenderung zurueck */
QDateTime  CVertrag::LiefereAenderungsdatum() const
{
 return Aenderungsdatum;
}

/* aendert das Datum der letzten Aenderung */
void CVertrag::AendereAenderungsdatum(QDateTime NDatum)
{
 Aenderungsdatum=NDatum;
}

/* prueft ob der Vertrag zulaessig ist */
/* hier immer TRUE da nicht genauer spezifiziert */
bool CVertrag::ZulaessigerVertrag(QString NVertragstext) const
{
 return TRUE;
}

bool CVertrag::readData(QDataStream* stream)
{
 int i;
 CDokument::readData(stream);
 *stream >> Vertragsnummer;
 *stream >> Aenderungsdatum;
 *stream >> i; UnterschriftBankVorhanden = (bool)i; //QDataStream kann kein bool
 *stream >> i; UnterschriftKundeVorhanden = (bool)i;
 *stream >> Vertragstext;
 return true;
}

bool CVertrag::writeData(QDataStream* stream) const
{
 CDokument::writeData(stream);
 *stream << Vertragsnummer;
 *stream << Aenderungsdatum;
 *stream << (int)UnterschriftBankVorhanden;
 *stream << (int)UnterschriftKundeVorhanden;
 *stream << Vertragstext;
 return true;
}
















